<?php

namespace Drupal\theme_compiler\Plugin;

use Drupal\Core\Plugin\DefaultPluginManager;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;

/**
 * Defines the compiler plugin manager provided by this module.
 */
class ThemeCompilerPluginManager extends DefaultPluginManager {

  /**
   * Constructs a ThemeCompilerPluginManager used to provide theme compilers.
   *
   * @param \Traversable $namespaces
   *   An object that implements \Traversable which contains the root paths
   *   keyed by the corresponding namespace to look for plugin implementations.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache_backend
   *   Cache backend instance to use.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler to invoke the alter hook with.
   */
  public function __construct(
    \Traversable $namespaces,
    CacheBackendInterface $cache_backend,
    ModuleHandlerInterface $module_handler
  ) {
    parent::__construct(
      'Plugin/ThemeCompiler',
      $namespaces,
      $module_handler,
      'Drupal\\theme_compiler\\Plugin\\ThemeCompilerPluginInterface',
      'Drupal\\theme_compiler\\Annotation\\ThemeCompiler'
    );

    $this->alterInfo('theme_compiler_info');
    $this->setCacheBackend($cache_backend, 'theme_compiler_plugins');
  }

}
